summaryrefslogtreecommitdiff
path: root/test/integration/nickserver_test.rb
diff options
context:
space:
mode:
Diffstat (limited to 'test/integration/nickserver_test.rb')
-rw-r--r--test/integration/nickserver_test.rb95
1 files changed, 41 insertions, 54 deletions
diff --git a/test/integration/nickserver_test.rb b/test/integration/nickserver_test.rb
index b4ff4da..710c3a1 100644
--- a/test/integration/nickserver_test.rb
+++ b/test/integration/nickserver_test.rb
@@ -4,18 +4,28 @@ require 'json'
#
# Some important notes to understanding these tests:
#
# (1) Requests to localhost always bypass HTTP stub.
#
# (2) All requests to nickserver are to localhost.
#
# (3) the "Host" header for requests to nickserver must be set (or Config.domain set)
#
# (4) When stubbing requests to couchdb, the couchdb host is changed from the
# default (localhost) to a dummy value (notlocalhost).
#
class NickserverTest < Minitest::Test
+ def setup
+ super
+ Celluloid.boot
+ end
+
+ def teardown
+ Celluloid.shutdown
+ super
+ end
+
def test_GET_served_via_SKS
uid = 'cloudadmin@leap.se'
key_id = 'E818C478D3141282F7590D29D041EB11B1647490'
@@ -24,9 +34,8 @@ class NickserverTest < Minitest::Test
start do
params = {query: {"address" => uid}}
- get(params) do |http|
- assert_equal file_content(:leap_public_key), JSON.parse(http.response)["openpgp"]
- stop
+ get(params) do |response|
+ assert_equal file_content(:leap_public_key), JSON.parse(response.to_s)["openpgp"]
end
end
end
@@ -39,9 +48,8 @@ class NickserverTest < Minitest::Test
start do
params = {body: {"address" => uid}}
- post(params) do |http|
- assert_equal file_content(:leap_public_key), JSON.parse(http.response)["openpgp"]
- stop
+ post(params) do |response|
+ assert_equal file_content(:leap_public_key), JSON.parse(response.to_s)["openpgp"]
end
end
end
@@ -51,10 +59,9 @@ class NickserverTest < Minitest::Test
uid = "bananas@" + domain
stub_couch_response(uid, status: 404) do
start do
- params = {query: {"address" => uid}, head: {host: domain}}
- get(params) do |http|
- assert_equal 404, http.response_header.status
- stop
+ params = {query: {"address" => uid}, head: {"Host" => domain}}
+ get(params) do |response|
+ assert_equal 404, response.code
end
end
end
@@ -66,9 +73,8 @@ class NickserverTest < Minitest::Test
stub_couch_response(uid, body: file_content(:empty_couchdb_result)) do
start do
params = {query: {"address" => uid}, head: {host: domain}}
- get(params) do |http|
- assert_equal 404, http.response_header.status
- stop
+ get(params) do |response|
+ assert_equal 404, response.code
end
end
end
@@ -79,10 +85,9 @@ class NickserverTest < Minitest::Test
uid = "blue@" + domain
stub_couch_response(uid, body: file_content(:blue_couchdb_result)) do
start do
- params = {query: {"address" => uid}, head: {host: domain}}
- get(params) do |http|
- assert_equal file_content(:blue_nickserver_result), http.response
- stop
+ params = {query: {"address" => uid}, head: {"Host" => domain}}
+ get(params) do |response|
+ assert_equal file_content(:blue_nickserver_result), response.to_s
end
end
end
@@ -90,9 +95,8 @@ class NickserverTest < Minitest::Test
def test_GET_empty
start do
- get({}) do |http|
- assert_equal "404 Not Found\n", http.response
- stop
+ get({}) do |response|
+ assert_equal "404 Not Found\n", response.to_s
end
end
end
@@ -103,53 +107,36 @@ class NickserverTest < Minitest::Test
# start nickserver
#
def start(timeout = 1)
- Timeout::timeout(timeout) do
- EM.run do
- Nickserver::Server.start
- EM.epoll
- yield
- end
- end
- rescue Timeout::Error
- flunk 'EventMachine was not stopped before the timeout expired'
+ server = Nickserver::ReelServer.new '127.0.0.1', config.port
+ yield server
+ ensure
+ server.terminate if server && server.alive?
end
#
# http GET requests to nickserver
#
- def get(params, &block)
- request(:get, params, &block)
+ def get(options = {}, &block)
+ request(:get, params: options[:query], head: options[:head], &block)
end
#
# http POST requests to nickserver
#
- def post(params, &block)
- request(:post, params, &block)
+ def post(options, &block)
+ request(:post, params: options[:body], head: options[:head], &block)
end
#
# http request to nickserver
#
- # this works because http requests to localhost are not stubbed, but requests to other domains are.
- #
- def request(method, params)
- EventMachine::HttpRequest.new("http://localhost:#{Nickserver::Config.port}/").send(method,params).callback {|http|
- # p http.response_header.status
- # p http.response_header
- # p http.response
- yield http
- }.errback {|http|
- flunk(http.error) if http.error
- EM.stop
- }
- end
-
- #
- # stop nickserver
+ # this works because http requests to 127.0.0.1 are not stubbed, but requests to other domains are.
#
- def stop
- EM.stop
+ def request(method, options = {})
+ response = HTTP.
+ headers(options.delete(:head)).
+ request method, "http://127.0.0.1:#{config.port}/", options
+ yield response
end
end
@@ -4,18 +4,28 @@ require 'json'
# Some important notes to understanding these tests:
#
-# (1) Requests to localhost always bypass HTTP stub.
+# (1) Requests to 127.0.0.1 always bypass HTTP stub.
#
@@ -4,18 +4,28 @@ require 'json'
#
-# (2) All requests to nickserver are to localhost.
+# (2) All requests to nickserver are to 127.0.0.1.
#
# (3) the "Host" header for requests to nickserver must be set (or Config.domain set)
@@ -4,18 +4,28 @@ require 'json'
#
# (4) When stubbing requests to couchdb, the couchdb host is changed from the
-# default (localhost) to a dummy value (notlocalhost).
+# default (127.0.0.1) to a dummy value (notlocalhost).
#
class NickserverTest < Minitest::Test